#!/bin/bash
echo "BEGIN COPYRIGHT"
echo "*************************************************************************"
echo "Licensed Materials - Property of IBM "
echo "5724-L01, 5655-N53, 5724-I82, 5655-R15"
echo "(C) Copyright IBM Corporation 2004, 2006. All rights reserved. "
echo "US Government Users Restricted Rights - Use, duplication, or disclosure"
echo "restricted by GSA ADP Schedule Contract with IBM Corp."
echo "*************************************************************************"
echo "END COPYRIGHT"
echo -e -n "\n"

function usage
{
    echo "Usage: DBUtility action [args...]"
    echo -e -n "\n"
    echo "Where action includes:"
    echo "    createDB            create a new database"
    echo "    createTable         create tables with given sql script on given Database"
    echo "    createJDBCProvider  create new JDBCProvider"
    echo "    createDataSource    create new DataSource for given JDBCProvider"
    echo -e -n "\n"
    echo "Where args include:"
    echo '   "createDB" is the action, following args are needed:'
    echo "       -DprofilePath=<profilePath>   The path of profile"
    echo "       -DdbType=<dbtype>             The database type"
    echo "       -DprofileName=<profileName>   The name of the profile"
    echo "       -DdbCreateNew=<boolean>       The Flag is to be true to create DB"
    echo "       -DdbName=<dbName>             The database name or alias name"
    echo "       -DdbLocation=<dbLocation>     The path of database install root"
    echo "       -DdbUserId=<dbUserId>         The user id to access database"
    echo "       -DdbPassword=<dbPassword>     The password to access the database"
    echo "       -DdbInstance=<dbInstance>     The database instance name --only required for Informix"
    echo "       -DdbSchemaName=<dbSchemaName> The schema name"
    echo "       -DdbServerName=<dbServerName> The database server name --only required for Sybase"
    echo -e -n "\n"
    echo '   "createTable" is the action, following args are needed:'
    echo "       -DprofilePath=<profilePath>   The path of profile"
    echo "       -DprofileName=<profileName>   The name of the profile"
    echo "       -DdbDelayConfig=<boolean>     The Flag is to be false to create Tables"
    echo "       -DdbType=<dbtype>             The database type"
    echo "       -DdbName=<dbName>             The database name or alias name"
    echo "       -DsqlScriptPath.default=<defautlSqlPath>"
    echo "	 		               The default sql script for creating table"
    echo "                                     DBUtility will attempt to find sql script for each database type"
    echo "                                     in this naming convention <defautlSqlPath>_<dbType>.sql."
    echo "                                     DBUtility will run <defautlSqlPath>,"
    echo "                                     if <defautlSqlPath>_<dbType>.sql does not exist."
    echo "       -DsqlScriptName.default=<defautlSqlScriptName>"
    echo "	 		               The default sql script for creating table"
    echo "                                     DBUtility will attempt to form a sql script path for each database type"
    echo "                                     in this naming convention <defautlSqlScriptName>_<dbType>.sql."
    echo "                                     DBUtility will run <defautlSqlScriptName>,"
    echo "                                     if <defautlSqlScriptName>_<dbType>.sql does not exist."    
    echo "       -DdbHostName=<dbHostName>     The host name or IP address for database server"
    echo "       -DdbServerPort=<dbServerPort> The JDBC port number for database server"
    echo "       -DdbJDBCClasspath=<dbJDBCClasspath>"
    echo "				       The directory path which contains JDBC driver files"
    echo "       -DdbUserId=<dbUserId>         The user id to access database"
    echo "       -DdbPassword=<dbPassword>     The password to access the database"
    echo "       -DdbInstance=<dbInstance>     The database instance name --only required for Informix"
    echo "       -DdbSchemaName=<dbSchemaName> The schema name"
    echo "       -DdbConnectionLocation=<dbConnectionLocation>"
    echo "				       The database connection location --only required for zOS"
    echo "       -DdbStorageGroup=<dbStorageGroup>"
    echo "			               The database storage group --only required for zOS"
    echo "       -DdbJDBCProperties=<dbJDBCProperties>"
    echo "			               The directory containing DB2JccConfiguration.properties --only required for zOS"
    echo -e -n "\n"
    echo '   "createJDBCProvider" is the action, following args are needed:'
    echo "       -DprofilePath=<profilePath>   The path of profile"
    echo "       -DprofileName=<profileName>   The name of the profile"
    echo "       -DdbType=<dbtype>             The database type"
    echo "       -DdbJDBCClasspath=<dbJDBCClasspath>"
    echo "			               The directory path which contains JDBC driver files"
    echo '       -DscopeLevel=<scopeLevel>     The scope level, valid values are "node", "cell"'
    echo "       -DcellName=<cellName>         The cell name"
    echo "       -DnodeName=<nodeName>         The node name"
    echo -e -n "\n"
    echo '   "createDataSource" is the action, following args are needed:'
    echo "       -DjndiName=<jndiName>         The dataSource jndiName"
    echo "       -DprofilePath=<profilePath>   The path of profile"
    echo "       -DprofileName=<profileName>   The name of profile"
    echo "       -DdbType=<dbtype>             The database type"
    echo "       -DdbName=<dbName>             The database name or alias name"
    echo "       -DdbHostName=<dbHostName>     The host name or IP address for database server"
    echo "       -DdbServerPort=<dbServerPort> The JDBC port number for database server"
    echo "       -DdbUserId=<dbUserId>         The user id to access database"
    echo "       -DdbPassword=<dbPassword>     The password to access the database"
    echo "       -DdbInstance=<dbInstance>     The database instance name --only required for Informix"
    echo "       -DdbSchemaName=<dbSchemaName> The schema name"
    echo "       -DdbConnectionLocation=<dbConnectionLocation>"
    echo "				       The database connection location --only required for zOS"
    echo "       -DdbStorageGroup=<dbStorageGroup>"
    echo "			               The database storage group --only required for zOS"
    echo "       -DdbJDBCClasspath=<dbJDBCClasspath>"
    echo "			               The directory path which contains JDBC driver files"    
    echo '       -DscopeLevel=<scopeLevel>     The scope level, valid values are "node", "cell"'
    echo "       -DcellName=<cellName>         The cell name"
    echo "       -DnodeName=<nodeName>         The node name"
    return
}

ACTION="HELP"

if [ -n "$1" ]
then
    case "$1" in
	"createDB" )
	    ACTION="createDB"
	    ;;
	"createTable" )
	    ACTION="createTable"
	    ;;
	"createJDBCProvider" )
	    ACTION="createJDBCProvider"
	    ;;
	"createDataSource" )
	    ACTION="createDataSource"
	    ;;
	"-h" )
	    usage
	    exit
	    ;;
	"--h" )
	    usage
	    exit
	    ;;
	"-help" )
	    usage
	    exit
	    ;;
	"--help" )
	    usage
	    exit
	    ;;
	"?" )
	    usage
	    exit
	    ;;
	* )
	    usage
	    exit
	    ;;
    esac
else
    usage
    exit
fi

binDir=`dirname $0`
. $binDir/setupCmdLine.sh

TEMPLATE_PATH=${WAS_HOME}/profileTemplates/default.wbicore

WS_CMT_LOG_HOME=${WAS_HOME}/logs/manageprofiles

# ----------------------------------
# ACTION=createJDBCProvider
# ----------------------------------
if [ $ACTION = "createJDBCProvider" ]
then
    PRE_ACTION="createVariables.dbType createVariables.db2.universal createVariables.db2.zos"
    
    # startWsadminListener
    ${WAS_HOME}/bin/ws_ant.sh -file ${TEMPLATE_PATH}/actions/launchWsAdminListener.ant -DWAS_HOME=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DprofilePath=${profilePath} -DprofileName=${profileName} 
    
    echo "${WAS_HOME}/bin/ws_ant.sh -file ${WAS_HOME}/util/dbUtils/profileHelpers/commonDBUtility.ant $PRE_ACTION $* -Dwbi.install.root=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DWAS_HOME=${WAS_HOME}"
    
    ${WAS_HOME}/bin/ws_ant.sh -file ${WAS_HOME}/util/dbUtils/profileHelpers/commonDBUtility.ant $PRE_ACTION $* -Dwbi.install.root=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DWAS_HOME=${WAS_HOME}
    
    # stopWsadminListener
    ${WAS_HOME}/bin/ws_ant.sh -file ${TEMPLATE_PATH}/actions/stopWsAdminListener.ant -DprofilePath=${profilePath}
    
    exit    
fi

# ----------------------------------
# ACTION=createDataSource
# ----------------------------------
if [ $ACTION = "createDataSource" ]
then
    # startWsadminListener
    ${WAS_HOME}/bin/ws_ant.sh -file ${TEMPLATE_PATH}/actions/launchWsAdminListener.ant -DWAS_HOME=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DprofilePath=${profilePath} -DprofileName=${profileName} 
    
    echo "${WAS_HOME}/bin/ws_ant.sh -file ${WAS_HOME}/util/dbUtils/profileHelpers/commonDBUtility.ant $* -Dwbi.install.root=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DWAS_HOME=${WAS_HOME}"
    
    ${WAS_HOME}/bin/ws_ant.sh -file ${WAS_HOME}/util/dbUtils/profileHelpers/commonDBUtility.ant $* -Dwbi.install.root=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DWAS_HOME=${WAS_HOME}
    
    # stopWsadminListener
    ${WAS_HOME}/bin/ws_ant.sh -file ${TEMPLATE_PATH}/actions/stopWsAdminListener.ant -DprofilePath=${profilePath}
    
    exit    
fi

# ----------------------------------
# ACTION=createTable,createDB
# ----------------------------------
if [ $ACTION = "createTable" ] || [ $ACTION = "createDB" ]
then
    echo "${WAS_HOME}/bin/ws_ant.sh -file ${WAS_HOME}/util/dbUtils/profileHelpers/commonDBUtility.ant $* -Dwbi.install.root=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DWAS_HOME=${WAS_HOME}"
    
    ${WAS_HOME}/bin/ws_ant.sh -file ${WAS_HOME}/util/dbUtils/profileHelpers/commonDBUtility.ant $* -Dwbi.install.root=${WAS_HOME} -DWS_CMT_LOG_HOME=${WS_CMT_LOG_HOME} -DWAS_HOME=${WAS_HOME}
    
    exit    
fi